@@ -1,5 +1,8 @@
 use super::{Completion, Error, Result};
-use core::ops::{ControlFlow, FromResidual, Try};
+use core::{
+    convert::Infallible,
+    ops::{ControlFlow, FromResidual, Try},
+};
 use core::{fmt::Debug, num::NonZeroUsize};
 
 /// Bit indicating that an UEFI status code is an error
@@ -194,6 +197,15 @@ impl FromResidual for Status {
     }
 }
 
+impl FromResidual<core::result::Result<Infallible, Error>> for Status {
+    fn from_residual(r: core::result::Result<Infallible, Error>) -> Self {
+        match r {
+            Err(err) => err.status(),
+            Ok(infallible) => match infallible {},
+        }
+    }
+}
+
 // FIXME: This conversion will go away along with usage of the ucs2 crate
 
 impl From<ucs2::Error> for Status {
